var tv4 = require('tv4'),
    path = require('object-path');

/**
Checks the schema of the returned JSON object against a provided {@link http://json-schema.org/ JSON Schema}. This assertation utilizes the brilliant {@link https://github.com/geraintluff/tv4 tv4 library}. An optional dot notation argument allows a subelement of the JSON object to checked against a JSON schema. Amoungst others, this can confirm types, array lengths, required fields, min and max of numbers and string lengths. For more examples see the test/matchers/schema.js tests.
@alias module:chakram-expectation.schema
@param {String} [subelement] - if specified a subelement of the JSON body is checked, specified using dot notation 
@param {*} expectedSchema - a JSON schema object which should match the JSON body or the JSON body's subelement. For more details on format see {@link http://json-schema.org/ the JSON schema website}
@example 
it("should check that the returned JSON object satisifies a JSON schema", function () {
    var request = chakram.get("http://httpbin.org/get");
    expect(request).to.have.schema('headers', {"required": ["Host", "Accept"]});
    expect(request).to.have.schema({
        "type": "object",
        properties: {
            url: {
                type: "string"
            },
            headers: {
                type: "object"
            }
        }
    });
    return chakram.wait();
});
 */

module.exports = function (chai, utils) {

    utils.addMethod(chai.Assertion.prototype, 'schema', function () {
        
        var object = this._obj.body;
        var schema = arguments[arguments.length-1];
        
        if(arguments.length === 2) {
            object = path.get(object, arguments[0]);
            if(object === undefined || object === null) {
                throw new Error("could not find path '"+arguments[0]+"' in object "+JSON.stringify(this._obj.body)); 
            }
        }        
        
        var valid = tv4.validate(object, schema);
        
        this.assert(
            valid, 
            'expected body to match JSON schema '+JSON.stringify(schema)+'. error: ' + tv4.error, 
            'expected body to not match JSON schema ' + JSON.stringify(schema)
        );
    });
};